@@ -1,4 +1,5 @@
 #' Cache a list of available help files as LaTeX objects
+#' @param n Number of days to look back with default value of 365 days
 #'
 #' @inheritParams pkg_ref_cache
 #' @family package reference cache
@@ -6,6 +7,6 @@
 #' @importFrom cranlogs cran_downloads
 #' @return a \code{pkg_ref} object
 #' @keywords internal
-pkg_ref_cache.downloads <- function(x, ...) {
-  cran_downloads(x$name, from=Sys.Date()-365, to=Sys.Date())
+pkg_ref_cache.downloads <- function(x, n=365, ...) {
+  cran_downloads(x$name, from=Sys.Date()-n, to=Sys.Date())
 }
